import Taro, { Component } from '@tarojs/taro'
import { View, ScrollView, Block } from '@tarojs/components'
import HouseCard from '../../components/HouseCard'
import { queryPreselectionRecord } from '@/services/project'
import { connect } from '@tarojs/redux'
import ready from '@/utils/ready'
import Blank from '../../components/Blank'
import './index.scss'

@connect(
  ({ user }) => ({ ...user })
)

export default class Records extends Component {
  config = {
    navigationBarTitleText: '选房记录'
  }

  state = {
    recordList: []
  }
  componentWillMount() {
    ready.queue(() => {

      const { userInfo: { person: { personId } } } = this.props
      const params = {
        personId,
        pageNum: 1,
        pageSize: 999,
      }
      queryPreselectionRecord(params).then(res => {
        const list = res.records
        this.setState({
          recordList: list.filter(item => item.status == '1') || []
        })
      })
    })
  }
  toHouseDetail(item) {
    if (item.housingStatus == '0' || item.saleBatchStatus == '0') {
      Taro.showToast({ title: '当前销售批次或该房源已被取消发布', icon: 'none', duration: 2000 })
    } else {
      Taro.navigateTo({
        url: `/onlineSelling/pages/detail/index?id=${item.houseId}`
      })
    }
  }

  render() {
    const { recordList } = this.state

    return (
      <View className="records" >

        {
          !recordList.length ? <Blank tips="暂无预选记录" /> :
            <ScrollView scrollY>
              {
                recordList.map((item) => {
                  return (
                    <Block>
                      {item.status == '1' && <View className="carditem" key={item.preselectionRecordId} onClick={() => this.toHouseDetail(item)}>
                        <HouseCard summary={item} />
                      </View>}
                    </Block>
                  )
                })
              }
            </ScrollView >
        }

      </View >
    )
  }
}
